==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectangleSize/ts/ShapeRectangleSize_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineRectangleSize</name>
    <message>
        <source>Top Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - lewo</translatorcomment>
        <translation type="obsolete">Góra - lewo</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - prawo</translatorcomment>
        <translation type="obsolete">Góra - prawo</translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - lewo</translatorcomment>
        <translation type="obsolete">Dół - lewo</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - prawo</translatorcomment>
        <translation type="obsolete">Dół - prawo</translation>
    </message>
    <message>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="obsolete">Położenie</translation>
    </message>
    <message>
        <source>&amp;Width:</source>
        <translatorcomment>--google--
&amp;Szerokość papieru:
Minimalna &amp;szerokość:</translatorcomment>
        <translation type="obsolete">Szerokość:</translation>
    </message>
    <message>
        <source>&amp;Height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wysokość papieru:
&amp;Wysokość:</translatorcomment>
        <translation type="obsolete">&amp;Wysokość:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt odniesienia:</translation>
    </message>
    <message>
        <source>Rectangle with &amp;Size</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Prostokąt Rozmiar</translation>
    </message>
    <message>
        <source>Draw rectangle with position and size</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj prostokąt pozycji i wielkości</translation>
    </message>
</context>
<context>
    <name>ShapeRectangleSize</name>
    <message>
        <source>Top Left</source>
        <translation type="obsolete">Góra - lewo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="obsolete">Góra - prawo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="obsolete">Dół - lewo</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="obsolete">Dół - prawo</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="obsolete">Położenie</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeInit.js" line="+2"/>
        <source>Rectangle with &amp;Size</source>
        <translation type="unfinished">Prostokąt Rozmiar</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle with position and size</source>
        <translation type="unfinished">Narysuj prostokąt pozycji i wielkości</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSize.ui" line="+17"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+19"/>
        <source>&amp;Width:</source>
        <translation type="unfinished">Szerokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+30"/>
        <source>&amp;Height:</source>
        <translation type="unfinished">&amp;Wysokość:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="-10"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation type="unfinished">Punkt odniesienia:</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+101"/>
        <source>Create Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectangleSize/ts/ShapeRectangleSize_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineRectangleSize</name>
    <message>
        <source>Top Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - lewo</translatorcomment>
        <translation type="obsolete">Góra - lewo</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - prawo</translatorcomment>
        <translation type="obsolete">Góra - prawo</translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - lewo</translatorcomment>
        <translation type="obsolete">Dół - lewo</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - prawo</translatorcomment>
        <translation type="obsolete">Dół - prawo</translation>
    </message>
    <message>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="obsolete">Położenie</translation>
    </message>
    <message>
        <source>&amp;Width:</source>
        <translatorcomment>--google--
&amp;Szerokość papieru:
Minimalna &amp;szerokość:</translatorcomment>
        <translation type="obsolete">Szerokość:</translation>
    </message>
    <message>
        <source>&amp;Height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wysokość papieru:
&amp;Wysokość:</translatorcomment>
        <translation type="obsolete">&amp;Wysokość:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt odniesienia:</translation>
    </message>
    <message>
        <source>Rectangle with &amp;Size</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Prostokąt Rozmiar</translation>
    </message>
    <message>
        <source>Draw rectangle with position and size</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj prostokąt pozycji i wielkości</translation>
    </message>
</context>
<context>
    <name>ShapeRectangleSize</name>
    <message>
        <source>Top Left</source>
        <translation type="obsolete">Góra - lewo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="obsolete">Góra - prawo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="obsolete">Dół - lewo</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="obsolete">Dół - prawo</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="obsolete">Położenie</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeInit.js" line="+2"/>
        <source>Rectangle with &amp;Size</source>
        <translation>Prostokąt o &amp;wymiarach</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle with position and size</source>
        <translation>Rysuje prostokąt w obranym położeniu i zadanej wielkości</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSize.ui" line="+17"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+19"/>
        <source>&amp;Width:</source>
        <translation>&amp;Szerokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+30"/>
        <source>&amp;Height:</source>
        <translation>&amp;Wysokość:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="-10"/>
        <source>Angle:</source>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Punkt odniesienia:</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+101"/>
        <source>Create Polyline</source>
        <translation>Utworzenie linii łamanej</translation>
    </message>
</context>
</TS>
